import{P as _}from"./PlayerNavbar.94fefbb4.js";import{a as m,i as f}from"./workspaceStore.1dfebc80.js";import{d as h,ek as g,e7 as s,f as y,r as b,W as v,b as r,u as i,a as w,o as L,$ as k}from"./vue-router.97d0d8a6.js";import"./metadata.7dbff146.js";import"./PhBug.vue.3ea7349b.js";import"./PhCheckCircle.vue.2e3af5ba.js";import"./PhKanban.vue.949c555a.js";import"./PhWebhooksLogo.vue.10394676.js";import"./PhSignOut.vue.3ede16d6.js";import"./index.8472dd28.js";import"./Avatar.ea229645.js";import"./url.6a6403b0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d20e5a52-7246-43a0-b9e9-f97fad1113e9",t._sentryDebugIdIdentifier="sentry-dbid-d20e5a52-7246-43a0-b9e9-f97fad1113e9")}catch{}})();const I={class:"main-container"},N={class:"content"},x=h({__name:"Main",setup(t){const e=g(),o=m(),c=s().path,u=({path:n})=>{e.push({path:`/${n}`})},d=()=>{e.push({name:"playerLogin"})},p=y(()=>!!s().meta.hideLogin);return f(()=>e.push({name:"playerLogin"})),(n,C)=>{var a;const l=b("RouterView");return L(),v("div",I,[r(_,{"current-path":i(c),"user-email":(a=i(o).user)==null?void 0:a.claims.email,"hide-login":p.value,onNavigate:u,onLoginClick:d},null,8,["current-path","user-email","hide-login"]),w("section",N,[r(l)])])}}});const q=k(x,[["__scopeId","data-v-9c4cb6a6"]]);export{q as default};
//# sourceMappingURL=Main.c150451e.js.map
