.data-container[data-v-24845f55]{height:100px}.description[data-v-b2ed6a6d]{margin-bottom:20px;font-style:italic;display:block}.form-settings[data-v-aff64cb2]{height:100%;overflow:auto;box-sizing:border-box;padding:0 0 20px}.form-preview-container[data-v-75e86c4d]{display:flex;flex-direction:column;border-radius:10px;overflow:hidden;height:100%;position:relative}.runner[data-v-75e86c4d]{flex-grow:1;overflow:hidden}
