import{B as d}from"./BookOutlined.868baafb.js";import{d as c,o as a,c as l,w as o,b as f,u as n,Z as u,W as i,ax as p,aJ as b,bL as y}from"./vue-router.97d0d8a6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="02eb4462-14d0-4a28-b393-52e6d0c64cc8",t._sentryDebugIdIdentifier="sentry-dbid-02eb4462-14d0-4a28-b393-52e6d0c64cc8")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[f(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.05d4ef76.js.map
