import{L as k}from"./Logo.9aca3b57.js";import{d as v,e7 as x,ek as A,f as w,W as I,b as d,w as a,u as e,c as p,R as f,eE as o,o as l,ax as s,e6 as u,d5 as C,d1 as m,bL as N,a as B,d2 as D,$ as E}from"./vue-router.97d0d8a6.js";import{u as T}from"./workspaceStore.1dfebc80.js";import{C as L}from"./Card.d83ffd8b.js";import"./url.6a6403b0.js";import"./TabPane.1a05f343.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new H().stack;c&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[c]="db0b9bb6-b98b-42a8-9520-6510021b62a1",r._sentryDebugIdIdentifier="sentry-dbid-db0b9bb6-b98b-42a8-9520-6510021b62a1")}catch{}})();const V={class:"inner-content"},R={class:"card-content"},S=v({__name:"Error",setup(r){const c=x(),b=A(),i=T(),g=w(()=>{var t,_,y;return(y=(t=i.state.workspace)==null?void 0:t.name)!=null?y:(_=i.state.workspace)==null?void 0:_.brandName}),n=w(()=>{const{status:t}=c.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),h=()=>{b.push({name:"playerHome"})};return(t,_)=>(l(),I("div",V,[d(e(C),null,{default:a(()=>[s(u(n.value.title),1)]),_:1}),d(e(m),{class:"message"},{default:a(()=>[s(u(n.value.message),1)]),_:1}),n.value.action?(l(),p(e(N),{key:0,type:"link",onClick:h},{default:a(()=>[s(u(n.value.action),1)]),_:1})):f("",!0),n.value.showAd?(l(),p(e(L),{key:1,bordered:!1,class:"card"},{default:a(()=>[B("div",R,[d(k,{style:{"margin-bottom":"10px"}}),d(e(m),null,{default:a(()=>[s("This page is part of "+u(g.value?`the ${g.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(i).state.workspace?(l(),p(e(m),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),d(e(D),{href:"https://abstra.io"},{default:a(()=>[s("here")]),_:1}),s(".")]),_:1})):f("",!0)])]),_:1})):f("",!0)]))}});const H=E(S,[["__scopeId","data-v-623dafe1"]]);export{H as default};
//# sourceMappingURL=Error.c7d46006.js.map
