import{d as i,c as n,w as p,o as a,b as s,u as r}from"./vue-router.97d0d8a6.js";import"./linters.9a4c6a1e.js";import{W as m}from"./workspaces.95ddd972.js";import{C as f}from"./ContentLayout.e60f6cb7.js";import{_ as d,E as u}from"./View.vue_vue_type_script_setup_true_lang.c8915af7.js";import"./asyncComputed.72143f3b.js";import"./workspaceStore.1dfebc80.js";import"./url.6a6403b0.js";import"./record.a84b6d90.js";import"./gateway.91a35dd3.js";import"./popupNotifcation.80047f06.js";import"./fetch.7ebcae96.js";import"./SaveButton.9c3f3c1d.js";import"./ExclamationCircleOutlined.25d26dfe.js";import"./CrudView.797f086e.js";import"./router.bf9d2a86.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.05d4ef76.js";import"./BookOutlined.868baafb.js";import"./PhDotsThree.vue.3d83613d.js";import"./index.557e8025.js";import"./PhRocketLaunch.vue.3b01d101.js";import"./PhPencil.vue.bb6c5a6a.js";import"./index.8765b89e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6e65f227-f91e-413e-a4ef-37270a1fa539",e._sentryDebugIdIdentifier="sentry-dbid-6e65f227-f91e-413e-a4ef-37270a1fa539")}catch{}})();const q=i({__name:"EnvVarsEditor",setup(e){const o=new u;return(t,c)=>(a(),n(f,null,{default:p(()=>[s(d,{"env-var-repository":r(o),mode:"editor","file-opender":r(m)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{q as default};
//# sourceMappingURL=EnvVarsEditor.6a1c03bf.js.map
