import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.c8915af7.js";import{d as s,e7 as i,c,u as a,o as m}from"./vue-router.97d0d8a6.js";import"./gateway.91a35dd3.js";import"./popupNotifcation.80047f06.js";import"./fetch.7ebcae96.js";import"./record.a84b6d90.js";import"./SaveButton.9c3f3c1d.js";import"./ExclamationCircleOutlined.25d26dfe.js";import"./CrudView.797f086e.js";import"./router.bf9d2a86.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.05d4ef76.js";import"./BookOutlined.868baafb.js";import"./url.6a6403b0.js";import"./PhDotsThree.vue.3d83613d.js";import"./index.557e8025.js";import"./PhRocketLaunch.vue.3b01d101.js";import"./asyncComputed.72143f3b.js";import"./PhPencil.vue.bb6c5a6a.js";import"./index.8765b89e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="02cec1c7-d989-4821-9432-0570a9665ecf",o._sentryDebugIdIdentifier="sentry-dbid-02cec1c7-d989-4821-9432-0570a9665ecf")}catch{}})();const $=s({__name:"EnvVars",setup(o){const r=i().params.projectId,t=new p(r);return(d,f)=>(m(),c(n,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{$ as default};
//# sourceMappingURL=EnvVars.3bcdd970.js.map
