import{b as o,eb as c,ev as u}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c2c4be4d-778e-4eea-9ce0-fb728c4b9832",e._sentryDebugIdIdentifier="sentry-dbid-c2c4be4d-778e-4eea-9ce0-fb728c4b9832")}catch{}})();function d(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){f(e,i,n[i])})}return e}function f(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=d({},t,n.attrs);return o(c,d({},r,{icon:u}),null)};a.displayName="LoadingOutlined";a.inheritAttrs=!1;const b=a;export{b as L};
//# sourceMappingURL=LoadingOutlined.fae5356f.js.map
