import{d as n,W as s,a,Z as d,e4 as r,o as l,$ as _}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="14b327b3-d74b-47be-a34d-c0aab84e5eb9",e._sentryDebugIdIdentifier="sentry-dbid-14b327b3-d74b-47be-a34d-c0aab84e5eb9")}catch{}})();const c={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",c,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[d(t.$slots,"default",{},void 0,!0)],2)]))}});const b=_(u,[["__scopeId","data-v-6397d501"]]);export{b as C};
//# sourceMappingURL=ContentLayout.e60f6cb7.js.map
