import{C as y}from"./ContentLayout.e60f6cb7.js";import{d as w,L as c,N as b,e as g,c as e,w as f,o as i,b as n,u as o,R as s}from"./vue-router.97d0d8a6.js";import{K as _,_ as v,W as K,E as R,a as E}from"./WorkflowView.d8f4638b.js";import{E as T}from"./api.5a5fe7cd.js";import{A as p,T as V}from"./TabPane.1a05f343.js";import"./fetch.7ebcae96.js";import"./linters.9a4c6a1e.js";import"./asyncComputed.72143f3b.js";import"./scripts.720b8af5.js";import"./record.a84b6d90.js";import"./metadata.7dbff146.js";import"./PhBug.vue.3ea7349b.js";import"./PhCheckCircle.vue.2e3af5ba.js";import"./PhKanban.vue.949c555a.js";import"./PhWebhooksLogo.vue.10394676.js";import"./PhQuestion.vue.5c222528.js";import"./ant-design.c0f2ec4c.js";import"./index.557e8025.js";import"./index.fea6fb81.js";import"./index.10085769.js";import"./CollapsePanel.7ce5e5d8.js";import"./index.9498a0e3.js";import"./index.4c3aef8d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.4c11c0db.js";import"./model.6f823b9d.js";import"./workspaces.95ddd972.js";import"./workspaceStore.1dfebc80.js";import"./url.6a6403b0.js";import"./validations.065d0e04.js";import"./string.4a3650cc.js";import"./PhArrowSquareOut.vue.93a854fa.js";import"./index.69a49651.js";import"./Badge.51321248.js";import"./index.8765b89e.js";import"./Card.d83ffd8b.js";import"./uuid.159751e6.js";import"./LoadingOutlined.fae5356f.js";import"./DeleteOutlined.8b1ac2ac.js";import"./PhDownloadSimple.vue.497bc358.js";import"./utils.8691b29e.js";import"./LoadingContainer.ffaf659c.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="81290c22-1691-434f-9432-262421db35ad",r._sentryDebugIdIdentifier="sentry-dbid-81290c22-1691-434f-9432-262421db35ad")}catch{}})();const wo=w({__name:"WorkflowThreads",setup(r){const t=new R,m=new E,d=new c(b.array(b.string()),"kanban-selected-stages"),u=new T,a=g("kanban");return(W,l)=>(i(),e(y,{"full-width":""},{default:f(()=>[n(o(V),{activeKey:a.value,"onUpdate:activeKey":l[0]||(l[0]=k=>a.value=k)},{default:f(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(i(),e(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),a.value==="table"?(i(),e(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),a.value==="workflow"?(i(),e(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{wo as default};
//# sourceMappingURL=WorkflowThreads.59971b81.js.map
