import{C as t,E as i,K as c,a as d,M as f,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.dcfee767.js";import"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1e1cf05c-3c53-4a83-a2c7-433cb2a257a3",e._sentryDebugIdIdentifier="sentry-dbid-1e1cf05c-3c53-4a83-a2c7-433cb2a257a3")}catch{}})();export{t as CancellationTokenSource,i as Emitter,c as KeyCode,d as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.abb20a2f.js.map
