import{O as r}from"./workspaceStore.1dfebc80.js";import{d as l,V as i,W as u,b as a,w as d,u as n,o as c,ax as o,d5 as f,d4 as b}from"./vue-router.97d0d8a6.js";import"./url.6a6403b0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="315054cf-d1d6-4d20-8d42-ba8edd8ba9ff",e._sentryDebugIdIdentifier="sentry-dbid-315054cf-d1d6-4d20-8d42-ba8edd8ba9ff")}catch{}})();const m=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(n(f),null,{default:d(()=>[o("You're authenticated")]),_:1}),a(n(b),null,{default:d(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{m as default};
//# sourceMappingURL=OidcLoginCallback.3b1c2c71.js.map
