import{_ as d}from"./Login.vue_vue_type_script_setup_true_lang.c906623c.js";import{a as c}from"./workspaceStore.1dfebc80.js";import{d as _,ek as f,e7 as i,W as u,b as p,o as b,$ as m}from"./vue-router.97d0d8a6.js";import"./CircularLoading.5245b03b.js";import"./index.8765b89e.js";import"./url.6a6403b0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ff2ee36b-bdeb-4d18-a9e3-a0cafb81ad45",e._sentryDebugIdIdentifier="sentry-dbid-ff2ee36b-bdeb-4d18-a9e3-a0cafb81ad45")}catch{}})();const y={class:"runner"},l=_({__name:"Login",setup(e){const t=f(),o=i(),r=c(),a=async()=>{await r.signUp();const{redirect:s,...n}=o.query;if(s){await t.push({path:s,query:n,params:o.params});return}t.push({name:"playerHome",query:n})};return(s,n)=>(b(),u("div",y,[p(d,{onDone:a})]))}});const k=m(l,[["__scopeId","data-v-5b8c1f5f"]]);export{k as default};
//# sourceMappingURL=Login.be150c87.js.map
