import{O as r}from"./workspaceStore.1dfebc80.js";import{d as l,V as i,W as u,b as a,w as d,u as o,o as c,ax as n,d5 as f,d4 as b}from"./vue-router.97d0d8a6.js";import"./url.6a6403b0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4902313e-055b-40bd-9e27-d9830b5a5dcd",e._sentryDebugIdIdentifier="sentry-dbid-4902313e-055b-40bd-9e27-d9830b5a5dcd")}catch{}})();const m=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:d(()=>[n("You're authenticated")]),_:1}),a(o(b),null,{default:d(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{m as default};
//# sourceMappingURL=OidcLogoutCallback.46db6244.js.map
