import{ew as t,ex as r}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2f920c35-7a9e-4317-b21b-0b1c55fbbc9a",e._sentryDebugIdIdentifier="sentry-dbid-2f920c35-7a9e-4317-b21b-0b1c55fbbc9a")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.fea6fb81.js.map
