import{d,ee as c,f as _,o as a,W as n,R as r,ef as p,eg as i,a as l,$ as f}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="022bea5b-6344-4950-8ac5-752f923b4401",e._sentryDebugIdIdentifier="sentry-dbid-022bea5b-6344-4950-8ac5-752f923b4401")}catch{}})();const g="/assets/logo.0faadfa2.svg",u=e=>(p("data-v-45e099d5"),e=e(),i(),e),b={class:"logo"},y=u(()=>l("img",{class:"logo-img",src:g,alt:"Abstra Logo"},null,-1)),m={key:0},h=d({__name:"Logo",props:{hideText:{type:Boolean},size:{}},setup(e){const s=e;c(t=>({"6b21c5f6":o.value}));const o=_(()=>s.size==="large"?"60px":"40px");return(t,I)=>(a(),n("div",b,[y,t.hideText?r("",!0):(a(),n("span",m,"Abstra"))]))}});const x=f(h,[["__scopeId","data-v-45e099d5"]]);export{x as L};
//# sourceMappingURL=Logo.9aca3b57.js.map
