import{S as c,dw as i,dx as d}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5755b909-715f-4645-97c0-58ab189af08d",e._sentryDebugIdIdentifier="sentry-dbid-5755b909-715f-4645-97c0-58ab189af08d")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),u=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.46743a57.js.map
