import{d as a,o,W as s,b as d,u as r,bp as _,$ as i}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e5e420d3-8722-4810-983f-1aa0955b9485",e._sentryDebugIdIdentifier="sentry-dbid-e5e420d3-8722-4810-983f-1aa0955b9485")}catch{}})();const c={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",c,[d(r(_))]))}});const u=i(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.ffaf659c.js.map
