import{L as x}from"./LoadingContainer.ffaf659c.js";import{S as D}from"./SaveButton.9c3f3c1d.js";import{C as h,W as A}from"./model.6f823b9d.js";import{E as C}from"./api.5a5fe7cd.js";import{d as W,e as E,f as N,u as e,c as n,W as _,R as y,b as d,w as o,o as r,a as w,aJ as B,e9 as S,d4 as k,ax as c,e6 as f,ea as V,cH as G,d9 as L,$ as T}from"./vue-router.97d0d8a6.js";import{w as F}from"./metadata.7dbff146.js";import{a as M}from"./asyncComputed.72143f3b.js";import{A as H}from"./index.557e8025.js";import{A as I}from"./index.9498a0e3.js";import"./ExclamationCircleOutlined.25d26dfe.js";import"./workspaces.95ddd972.js";import"./workspaceStore.1dfebc80.js";import"./url.6a6403b0.js";import"./record.a84b6d90.js";import"./validations.065d0e04.js";import"./string.4a3650cc.js";import"./PhArrowSquareOut.vue.93a854fa.js";import"./index.69a49651.js";import"./Badge.51321248.js";import"./isNumeric.75337b1e.js";import"./index.8765b89e.js";import"./Card.d83ffd8b.js";import"./TabPane.1a05f343.js";import"./uuid.159751e6.js";import"./fetch.7ebcae96.js";import"./PhBug.vue.3ea7349b.js";import"./PhCheckCircle.vue.2e3af5ba.js";import"./PhKanban.vue.949c555a.js";import"./PhWebhooksLogo.vue.10394676.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[i]="3e76b685-9c78-47d8-8305-4ade3e06b4ef",s._sentryDebugIdIdentifier="sentry-dbid-3e76b685-9c78-47d8-8305-4ade3e06b4ef")}catch{}})();const J={key:1,class:"workflow-editor"},P={class:"workflow-toolbar"},R=["onDragstart"],$=W({__name:"WorkflowEditor",setup(s){const i=E(null),u=N(()=>{var a;return(a=i.value)==null?void 0:a.gui}),v=new C,{result:l,loading:b}=M(()=>A.create(v)),g=(a,m)=>{var t,p;(t=m.dataTransfer)==null||t.setData("type",a),(p=u.value)==null||p.dragstart(a,m)};return(a,m)=>e(b)?(r(),n(x,{key:0})):(r(),_("div",J,[e(l)?(r(),n(h,{key:0,ref_key:"canvasGui",ref:i,model:e(l)},null,8,["model"])):y("",!0),d(e(L),null,{default:o(()=>[w("div",P,[(r(!0),_(B,null,S(e(F).stages,t=>(r(),n(e(G),{key:t.typeName,placement:"top"},{title:o(()=>[d(e(H),null,{default:o(()=>[d(e(k),null,{default:o(()=>[c(f(t.title),1)]),_:2},1024),d(e(k),{keyboard:""},{default:o(()=>[c(f(t.key),1)]),_:2},1024)]),_:2},1024)]),content:o(()=>[c(f(t.description),1)]),default:o(()=>[w("span",{draggable:"true",onDragstart:p=>g(t.typeName,p)},[(r(),n(V(t.icon),{width:"18",height:"18",class:"toolbar-item"}))],40,R)]),_:2},1024))),128)),d(e(I),{type:"vertical"}),e(l)?(r(),n(D,{key:0,model:e(l),disabled:void 0,type:"primary"},null,8,["model"])):y("",!0)])]),_:1})]))}});const ve=T($,[["__scopeId","data-v-de9c06f6"]]);export{ve as default};
//# sourceMappingURL=WorkflowEditor.05c5fe69.js.map
