import{d as T,a8 as V,dK as J,dL as K,f as o,e as N,g as M,a9 as W,S as m,aI as q,b as f,aJ as H,ab as E,cO as h,am as G,bl as j,aE as Q}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="c921bb33-86e3-4927-be21-e1eb0c8414d2",e._sentryDebugIdIdentifier="sentry-dbid-c921bb33-86e3-4927-be21-e1eb0c8414d2")}catch{}})();const U={small:8,middle:16,large:24},X=()=>({prefixCls:String,size:{type:[String,Number,Array]},direction:G.oneOf(j("horizontal","vertical")).def("horizontal"),align:G.oneOf(j("start","end","center","baseline")),wrap:Q()});function Y(e){return typeof e=="string"?U[e]:e||0}const r=T({compatConfig:{MODE:3},name:"ASpace",inheritAttrs:!1,props:X(),slots:Object,setup(e,c){let{slots:l,attrs:g}=c;const{prefixCls:n,space:b,direction:x}=V("space",e),[B,F]=J(n),z=K(),s=o(()=>{var t,a,i;return(i=(t=e.size)!==null&&t!==void 0?t:(a=b==null?void 0:b.value)===null||a===void 0?void 0:a.size)!==null&&i!==void 0?i:"small"}),y=N(),u=N();M(s,()=>{[y.value,u.value]=(Array.isArray(s.value)?s.value:[s.value,s.value]).map(t=>Y(t))},{immediate:!0});const w=o(()=>e.align===void 0&&e.direction==="horizontal"?"center":e.align),k=o(()=>W(n.value,F.value,`${n.value}-${e.direction}`,{[`${n.value}-rtl`]:x.value==="rtl",[`${n.value}-align-${w.value}`]:w.value})),L=o(()=>x.value==="rtl"?"marginLeft":"marginRight"),P=o(()=>{const t={};return z.value&&(t.columnGap=`${y.value}px`,t.rowGap=`${u.value}px`),m(m({},t),e.wrap&&{flexWrap:"wrap",marginBottom:`${-u.value}px`})});return()=>{var t,a;const{wrap:i,direction:R="horizontal"}=e,_=(t=l.default)===null||t===void 0?void 0:t.call(l),I=q(_),C=I.length;if(C===0)return null;const d=(a=l.split)===null||a===void 0?void 0:a.call(l),A=`${n.value}-item`,D=y.value,S=C-1;return f("div",E(E({},g),{},{class:[k.value,g.class],style:[P.value,g.style]}),[I.map((O,v)=>{let $=_.indexOf(O);$===-1&&($=`$$space-${v}`);let p={};return z.value||(R==="vertical"?v<S&&(p={marginBottom:`${D/(d?2:1)}px`}):p=m(m({},v<S&&{[L.value]:`${D/(d?2:1)}px`}),i&&{paddingBottom:`${u.value}px`})),B(f(H,{key:$},[f("div",{class:A,style:p},[O]),v<S&&d&&f("span",{class:`${A}-split`,style:p},[d])]))})])}}});r.Compact=h;r.install=function(e){return e.component(r.name,r),e.component(h.name,h),e};const ee=r;export{ee as A};
//# sourceMappingURL=index.557e8025.js.map
