import{W as g}from"./Watermark.49365ee3.js";import{i as h}from"./metadata.7dbff146.js";import{F as k}from"./PhArrowSquareOut.vue.93a854fa.js";import{d as w,ek as b,f as x,u as e,W as m,b as o,w as r,R as v,o as s,c as p,ax as u,d1 as f,aJ as C,e9 as D,d9 as _,ea as I,e6 as F,$ as T}from"./vue-router.97d0d8a6.js";import{u as W}from"./workspaceStore.1dfebc80.js";import"./index.a4558ecd.js";import{C as z}from"./Card.d83ffd8b.js";import"./PhBug.vue.3ea7349b.js";import"./PhCheckCircle.vue.2e3af5ba.js";import"./PhKanban.vue.949c555a.js";import"./PhWebhooksLogo.vue.10394676.js";import"./url.6a6403b0.js";import"./TabPane.1a05f343.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="19428e93-e7cc-4c71-abd8-297e4415e89f",t._sentryDebugIdIdentifier="sentry-dbid-19428e93-e7cc-4c71-abd8-297e4415e89f")}catch{}})();const B={key:0,class:"home-container"},H=w({__name:"Home",setup(t){const n=b(),c=W(),d=x(()=>{var a;return((a=c.state.workspace)==null?void 0:a.sidebar.filter(l=>l.id!=="home"))||[]}),y=a=>{n.push({path:`/${a}`})};return(a,l)=>e(c).state.workspace?(s(),m("div",B,[o(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[d.value.length===0?(s(),p(e(f),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[u(" There are no forms available for you. ")]),_:1})):(s(!0),m(C,{key:1},D(d.value,i=>(s(),p(e(z),{key:i.id,class:"form-card",onClick:N=>y(i.path)},{default:r(()=>[o(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(s(),p(I(e(h)(i.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),o(e(f),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[u(F(i.name),1)]),_:2},1024),o(e(k),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),o(g,{class:"watermark","page-id":"home",locale:e(c).state.workspace.language},null,8,["locale"])])):v("",!0)}});const M=T(H,[["__scopeId","data-v-2ee244f8"]]);export{M as default};
//# sourceMappingURL=Home.960a87c2.js.map
