import{B as f}from"./BaseLayout.76b9d34c.js";import{L as y}from"./Logo.9aca3b57.js";import{d as u,D as m,K as g,$ as p,aR as v,aS as b,o as _,W as h,a as r,X as s,e7 as w,ek as S,V as L,c as k,w as n,b as i,u as x}from"./vue-router.97d0d8a6.js";import{u as B}from"./editor.784d7a70.js";import{b as I}from"./index.5452647c.js";import"./workspaceStore.1dfebc80.js";import"./url.6a6403b0.js";import"./linters.9a4c6a1e.js";import"./asyncComputed.72143f3b.js";import"./index.8472dd28.js";import"./Avatar.ea229645.js";import"./index.557e8025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1e091e2a-41f4-4d78-9070-834c2ce50006",e._sentryDebugIdIdentifier="sentry-dbid-1e091e2a-41f4-4d78-9070-834c2ce50006")}catch{}})();const $=u({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...g(o)}}});const D={class:"v-spinner"};function P(e,o,a,c,d,l){return v((_(),h("div",D,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=p($,[["render",P],["__scopeId","data-v-06538001"]]),K={class:"content"},j=u({__name:"ProjectLogin",setup(e){const o=w(),a=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=l();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"workspace"})}),(t,z)=>(_(),k(f,null,{navbar:n(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(y)]),_:1})]),content:n(()=>[r("div",K,[i(R)])]),_:1}))}});const G=p(j,[["__scopeId","data-v-6ca995fe"]]);export{G as default};
//# sourceMappingURL=ProjectLogin.66999b77.js.map
