import{a as k}from"./workspaceStore.1dfebc80.js";import{d as _,L as w,N as c,e as g,W as v,b as r,w as h,u as e,c as p,R as m,o as s,$ as T}from"./vue-router.97d0d8a6.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.d8f4638b.js";import{P as V}from"./api.5a5fe7cd.js";import{A as l,T as W}from"./TabPane.1a05f343.js";import"./Card.d83ffd8b.js";import"./url.6a6403b0.js";import"./fetch.7ebcae96.js";import"./linters.9a4c6a1e.js";import"./asyncComputed.72143f3b.js";import"./scripts.720b8af5.js";import"./record.a84b6d90.js";import"./metadata.7dbff146.js";import"./PhBug.vue.3ea7349b.js";import"./PhCheckCircle.vue.2e3af5ba.js";import"./PhKanban.vue.949c555a.js";import"./PhWebhooksLogo.vue.10394676.js";import"./PhQuestion.vue.5c222528.js";import"./ant-design.c0f2ec4c.js";import"./index.557e8025.js";import"./index.fea6fb81.js";import"./index.10085769.js";import"./CollapsePanel.7ce5e5d8.js";import"./index.9498a0e3.js";import"./index.4c3aef8d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.4c11c0db.js";import"./model.6f823b9d.js";import"./workspaces.95ddd972.js";import"./validations.065d0e04.js";import"./string.4a3650cc.js";import"./PhArrowSquareOut.vue.93a854fa.js";import"./index.69a49651.js";import"./Badge.51321248.js";import"./index.8765b89e.js";import"./uuid.159751e6.js";import"./LoadingOutlined.fae5356f.js";import"./DeleteOutlined.8b1ac2ac.js";import"./PhDownloadSimple.vue.497bc358.js";import"./utils.8691b29e.js";import"./LoadingContainer.ffaf659c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="6339f32a-34eb-4539-a794-3759c45622e5",t._sentryDebugIdIdentifier="sentry-dbid-6339f32a-34eb-4539-a794-3759c45622e5")}catch{}})();const x={class:"threads-view"},A=_({__name:"Threads",setup(t){const a=k().authHeaders,u=new V(a),i=new P(a),y=new S(a),d=new w(c.array(c.string()),"kanban-selected-stages"),o=g("kanban");return(B,b)=>(s(),v("div",x,[r(e(W),{activeKey:o.value,"onUpdate:activeKey":b[0]||(b[0]=f=>o.value=f)},{default:h(()=>[r(e(l),{key:"kanban",tab:"Kanban View"}),r(e(l),{key:"table",tab:"Table View"}),r(e(l),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(d),"stage-run-repository":e(y)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ve=T(A,[["__scopeId","data-v-86c0b860"]]);export{ve as default};
//# sourceMappingURL=Threads.65952a8c.js.map
