import{a as g}from"./asyncComputed.72143f3b.js";import{d as y,e7 as _,V as b,u as e,c as w,W as x,b as a,w as o,o as l,d5 as C,ax as p,d9 as h,bL as I,a as k,e6 as v}from"./vue-router.97d0d8a6.js";import"./gateway.91a35dd3.js";import{O as B}from"./organization.c9b277ba.js";import"./tables.8944c1e2.js";import{C as c}from"./router.bf9d2a86.js";import{L as D}from"./LoadingContainer.ffaf659c.js";import{A as N}from"./index.9498a0e3.js";import{C as z}from"./Card.d83ffd8b.js";import"./popupNotifcation.80047f06.js";import"./record.a84b6d90.js";import"./string.4a3650cc.js";import"./TabPane.1a05f343.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="d54d9859-e84e-463b-8cda-b34e230dbcd7",t._sentryDebugIdIdentifier="sentry-dbid-d54d9859-e84e-463b-8cda-b34e230dbcd7")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},J=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>B.get(s));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,L)=>e(u)?(l(),w(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{J as default};
//# sourceMappingURL=Billing.e6015664.js.map
