import{d as y,e2 as b,D as m,W as c,a as d,u as g,X as r,Z as u,R as w,e3 as h,e4 as S,o as l,$ as v,e as k,r as C,b as f,w as I,aJ as D}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4ec42a93-e8ce-4c6c-97f3-a0c618520ada",e._sentryDebugIdIdentifier="sentry-dbid-4ec42a93-e8ce-4c6c-97f3-a0c618520ada")}catch{}})();const V=y({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:s,emit:o}){const i=b(),_=()=>{a.isOpened=!0,o("open")},n=()=>{a.isOpened=!1,o("close")};s({open:_,close:n});const a=m({isOpened:!1});return(t,p)=>(l(),c("div",{class:S(["background",a.isOpened&&"visible"]),onClick:n},[d("div",{class:"container",style:r(t.containerStyle),onClick:p[0]||(p[0]=h(()=>{},["stop"]))},[g(i).header?(l(),c("div",{key:0,class:"header",style:r(t.headerStyle)},[u(t.$slots,"header",{},void 0,!0)],4)):w("",!0),d("div",{class:"content",style:r(t.contentStyle)},[u(t.$slots,"content",{},void 0,!0)],4)],4)],2))}});const M=v(V,[["__scopeId","data-v-4d878495"]]),O=["src"],$=y({__name:"Home",setup(e){const s=m({onboardingForm:""}),o=k(null);return(i,_)=>{const n=C("RouterView");return l(),c(D,null,[f(n,{class:"router"}),f(M,{ref_key:"modal",ref:o},{content:I(()=>[d("iframe",{class:"form",src:s.onboardingForm},null,8,O)]),_:1},512)],64)}}});const B=v($,[["__scopeId","data-v-f5f64833"]]);export{B as default};
//# sourceMappingURL=Home.be5688d4.js.map
