[data-v-d667e7b2]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.loading[data-v-d667e7b2]{position:absolute;top:0;left:0;width:100vw;height:100vh;display:flex;justify-content:center;align-items:center}.unset-thread-container[data-v-d667e7b2]{justify-content:center;align-items:center;height:100%}.unset-thread-container .message[data-v-d667e7b2]{width:420px;text-align:center;font-size:16px;margin-bottom:40px}
