import{b as i,eb as l,ey as u}from"./vue-router.97d0d8a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f67a7fe5-dd80-4db3-a7c8-fe873436d06f",e._sentryDebugIdIdentifier="sentry-dbid-f67a7fe5-dd80-4db3-a7c8-fe873436d06f")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(f){return Object.getOwnPropertyDescriptor(n,f).enumerable}))),r.forEach(function(f){o(e,f,n[f])})}return e}function o(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var d=function(t,n){var r=a({},t,n.attrs);return i(l,a({},r,{icon:u}),null)};d.displayName="DeleteOutlined";d.inheritAttrs=!1;const s=d;export{s as D};
//# sourceMappingURL=DeleteOutlined.8b1ac2ac.js.map
