import{d as i,g as c,r as p,u as a,o as d,c as u,w as m,b as l,R as f,k as _,T as w,m as g,P as y,C as h,M as k,s as v,n as o,p as b,q as C,t as I,v as W}from"./vue-router.97d0d8a6.js";import{a as S,u as V,s as A,c as D,b as n}from"./workspaceStore.1dfebc80.js";import{W as M}from"./WidgetsFrame.a8926a60.js";import"./url.6a6403b0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d774a561-d70a-4d24-9344-3307cc019170",t._sentryDebugIdIdentifier="sentry-dbid-d774a561-d70a-4d24-9344-3307cc019170")}catch{}})();const P=i({__name:"App",setup(t){const e=S(),s=V();return s.actions.fetch(),c(()=>e.user,s.actions.fetch),(R,B)=>{const r=p("RouterView");return a(s).state.workspace?(d(),u(M,{key:0,"main-color":a(s).state.workspace.mainColor,theme:a(s).state.workspace.theme,"font-family":a(s).state.workspace.fontFamily,locale:a(s).state.workspace.language},{default:m(()=>[l(r,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","theme","font-family","locale"])):f("",!0)}}});class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await A();const t=D(),e=_({render:()=>b(P)});w.init(),g(e,n),x.init(),e.use(n),e.use(t),e.use(y),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",k),e.component("Message",v),o(e,C),o(e,I),o(e,W)})();
//# sourceMappingURL=player.203c413f.js.map
