.inner-content[data-v-623dafe1]{display:flex;justify-content:center;align-items:center;flex-direction:column;height:100%;position:relative}.inner-content .message[data-v-623dafe1]{max-width:500px;text-align:center;font-size:16px;margin-bottom:40px}.inner-content .card[data-v-623dafe1]{margin-top:40px}.inner-content .card .card-content[data-v-623dafe1]{display:flex;flex-direction:column;align-items:center;justify-content:center}
